==> ocaml_4.05.0.orig.tar.xz: ocaml-4.05.0/otherlibs/unix/fchown.c <==
/**************************************************************************/
/*                                                                        */
/*                                 OCaml                                  */
/*                                                                        */
/*             Xavier Leroy, projet Cristal, INRIA Rocquencourt           */
/*                                                                        */
/*   Copyright 1996 Institut National de Recherche en Informatique et     */
/*     en Automatique.                                                    */
/*                                                                        */
/*   All rights reserved.  This file is distributed under the terms of    */
/*   the GNU Lesser General Public License version 2.1, with the          */
/*   special exception on linking described in the file LICENSE.          */
/*                                                                        */
/**************************************************************************/

#include <caml/fail.h>
#include <caml/mlvalues.h>
#include <caml/signals.h>
#include "unixsupport.h"

#ifdef HAS_FCHMOD

CAMLprim value unix_fchown(value fd, value uid, value gid)
{
  int result;
  caml_enter_blocking_section();
  result = fchown(Int_val(fd), Int_val(uid), Int_val(gid));
  caml_leave_blocking_section();
  if (result == -1) uerror("fchown", Nothing);
  return Val_unit;
}

#else

CAMLprim value unix_fchown(value fd, value uid, value gid)
{ caml_invalid_argument("fchown not implemented"); }

#endif

==> ocaml_5.4.0.orig.tar.xz: ocaml-5.4.0/otherlibs/unix/fchown.c <==
/**************************************************************************/
/*                                                                        */
/*                                 OCaml                                  */
/*                                                                        */
/*             Xavier Leroy, projet Cristal, INRIA Rocquencourt           */
/*                                                                        */
/*   Copyright 1996 Institut National de Recherche en Informatique et     */
/*     en Automatique.                                                    */
/*                                                                        */
/*   All rights reserved.  This file is distributed under the terms of    */
/*   the GNU Lesser General Public License version 2.1, with the          */
/*   special exception on linking described in the file LICENSE.          */
/*                                                                        */
/**************************************************************************/

#include <caml/fail.h>
#include <caml/mlvalues.h>
#include <caml/signals.h>
#include "caml/unixsupport.h"

#ifdef HAS_FCHMOD

CAMLprim value caml_unix_fchown(value fd, value uid, value gid)
{
  int result;
  caml_enter_blocking_section();
  result = fchown(Int_val(fd), Int_val(uid), Int_val(gid));
  caml_leave_blocking_section();
  if (result == -1) caml_uerror("fchown", Nothing);
  return Val_unit;
}

#else

CAMLprim value caml_unix_fchown(value fd, value uid, value gid)
{ caml_invalid_argument("fchown not implemented"); }

#endif
